---
name: Bug report
about: Create a report to help us improve
title: ''
labels: ''
assignees: ''

---

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
Steps to reproduce the behavior **please include attached any files needed to reproduce the error**. We can only help you if we can reproduce the error ourselves and debug.

**Expected behavior**
A clear and concise description of what you expected to happen.

**Desktop (please complete the following information):**
 - Operating System, version:
 - Python version:
 - Python-MIP version (we recommend you to test with the latest version):  

**Additional context**
Add any other context about the problem here.
